{
	"name" : "Localisation for France",
	"version" : "1.0",
	"author" : "Tiny",
	"category" : "Localisation/Account charts",
	"depends" : ["base", "account"],
	"init_xml" : [],
	"demo_xml" : [],
	"update_xml" : ["account_pcg_france.xml"],
	"active": False,
	"installable": True
}
